#
# spec file for package aseqview
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aseqview
Version:        0.2.8
Release:        5.2
Summary:        ALSA Sequencer Event Viewer
License:        GPL-2.0-only
URL:            https://github.com/tiwai/aseqview
Source:         %{name}-%{version}.tar.xz
Source1:        aseqview.desktop
Source2:        aseqview.png
Patch0:         aseqview-0.2.2.dif
Patch1:         aseqview-quote-macros.patch
Patch2:         aseqview-piano-segfault-fix.patch
BuildRequires:  alsa-devel
BuildRequires:  automake
BuildRequires:  gtk2-devel
BuildRequires:  update-desktop-files

%description
ASeqView is an ALSA sequencer user client that works as an event viewer
and event filter.  It visualizes received events, such as note on and
off, controls, and pitch wheels, using bar graphs as seen in many
sequencer applications.

%prep
%setup -q
%patch -P 0
%patch -P 1 -p1
%patch -P 2 -p1

%build
autoreconf --force --install
%configure --enable-gtk2
%make_build

%install
%make_install
%suse_update_desktop_file -i aseqview AudioVideo Music GTK
mkdir -p %{buildroot}%{_datadir}/pixmaps
cp %{SOURCE2} %{buildroot}%{_datadir}/pixmaps

%files
%{_bindir}/*
%license COPYING
%doc README AUTHORS ChangeLog
%{_mandir}/man*/*
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Jun 13 2021 tiwai@suse.de
- Fix segfault at piano widget creation with the recent gtk2
  (boo#1187239):
  aseqview-piano-segfault-fix.patch
* Thu Apr 22 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed and modernized SPEC file
  * Replace broken URL with latest upstream
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Jan 19 2016 tiwai@suse.de
- update to version 0.2.8;
  * Added ports to control tuning events
  * Ports are disabled per default, explicitly capable via -T option
  * Fix mix-up of g_free and free
  * Fix visualization of tuning information after reset.
    Default to C-tuning (dumper off) and Am-tuning (dumper on).
  * Fix playback of multiple songs keeping connection of tuning
    ports
* Tue Dec 13 2011 tiwai@suse.de
- fix license to GPL-2.0 only (bnc#735017)
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Fri Mar  5 2010 puzel@novell.com
- add aseqview-quote-macros.patch - fix build
- minor spec cleanup
* Wed Apr 25 2007 tiwai@suse.de
- fix desktop file to use GenericName
* Mon Apr 16 2007 tiwai@suse.de
- updated to version 0.2.7:
  * Add GM2 display
  * Allow multiple -d and -s options (also comma separated
    addresses)
  * Fix mute status control with multiple ports
* Tue Apr  3 2007 tiwai@suse.de
- updated to version 0.2.6:
  * Fix segfault with thread mode (silly typo)
  * Add mute-control feature by TAMUKI Shoichi
* Thu Mar 29 2007 tiwai@suse.de
- fix races in thread mode
* Mon Mar 26 2007 tiwai@suse.de
- updated to version 0.2.4:
  * Added MIDI Tunig Standard (MTS) feature
* Thu Feb 23 2006 tiwai@suse.de
- added GTK to Categories
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 11 2005 tiwai@suse.de
- updated to version 0.2.3a.
* Fri Oct 29 2004 ro@suse.de
- remove gtk from neededforbuild
* Thu Feb 26 2004 tiwai@suse.de
- updated to version 0.2.2.
  built with gtk2.
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Nov 20 2003 tiwai@suse.de
- updated to version 0.2.1.
* Mon Sep 15 2003 tiwai@suse.de
- fixed categories.
- added desktop icon.
* Thu Aug 21 2003 tiwai@suse.de
- updated to version 0.2.0.
- fixed desktop file categories.
* Tue Aug  5 2003 tiwai@suse.de
- added desktop file.
- call suse_update_desktop_file macro.
* Mon Nov 25 2002 tiwai@suse.de
- fixed neededforbuild: xf86 -> x-devel-packages.
- clean up spec file.
* Fri Jul 13 2001 tiwai@suse.de
- updated to ver.0.1.4.
- use _prefix and co.
- fixed file lists.
* Fri Nov 17 2000 tiwai@suse.de
- Use RPM_OPT_FLAGS to configure.
* Thu Nov  2 2000 tiwai@suse.de
- Fixed 0.1.2f archive.
* Thu Nov  2 2000 tiwai@suse.de
- Updated to version 0.1.2f.
- Fixed spec file for long package-name support.
- Use bzip2 for archive.
* Fri Jun  9 2000 tiwai@suse.de
- new package - ALSA sequencer event viewer
  version: 0.1.2e
